.. include:: ../README.rst


Links
^^^^^

* `PyPI homepage <https://pypi.org/project/gabbia/>`_
* `GitHub homepage <https://github.com/heuer/gabbia>`_
* `Issue tracker <https://github.com/heuer/gabbia/issues>`_


Contents
^^^^^^^^

.. toctree::
   :maxdepth: 2

   installation
   usage
   wayland-protocols
   man/index
   api
   changes


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
